@@ -553,11 +553,13 @@ typedef struct {
     char *historyFont;
     char *gameListFont;
     char *icsFont;
+    int analysisBell;
     Boolean ringBellAfterMoves;
     Boolean autoCallFlag;
     Boolean flipView;
     Boolean autoFlipView;
     char *cmailGameName; /* xboard only */
+    Boolean moveTime;
     Boolean headers;
     Boolean alwaysPromoteToQueen;
     Boolean oldSaveStyle;
@@ -576,6 +578,7 @@ typedef struct {
     Boolean localLineEditing; /* WinBoard only */
     Boolean zippyTalk;
     Boolean zippyPlay;
+    int jewelled;
     int flashCount; /* Number of times to flash (xboard only) */
     int flashRate; /* Flashes per second (xboard only)  */
     int msLoginDelay;  /* Delay per character (in msec) while sending
@@ -643,6 +646,7 @@ typedef struct {
     Boolean scoreIsAbsolute[ENGINES];  /* If true, engine score is always from white side */
     Boolean saveExtendedInfoInPGN; /* If true, saved PGN games contain extended info */
     Boolean hideThinkingFromHuman; /* If true, program thinking is generated but not displayed in human/computer matches */
+    Boolean cumulativeTimePGN;     /* If true, times saved in PGN extended info is time left on clock */
     Boolean useBitmaps;
     Boolean useFont;
     Boolean useBorder;
@@ -798,6 +802,10 @@ typedef struct {
 
     int recentEngines;
     char *recentEngineList;
+    char *message;
+    char *suppress;
+    char *fen;
+    char *men;
     char *tourneyFile;
     char *defName;
     char *processes;
