@@ -215,6 +215,8 @@ void CopyFENToClipboard P((void));
 extern char *programName;
 extern int commentUp;
 extern char *firstChessProgramNames;
+extern char *icsTextMenuString;
+extern int mute;
 
 void GreyRevert P((Boolean grey));
 void EnableNamedMenuItem P((char *menuRef, int state));
@@ -243,6 +245,7 @@ int  EvalGraphDialogExists P((void));
 void SlavePopUp P((void));
 void ActivateTheme P((int new));
 char *Col2Text P((int n));
+char *Shorten P((char *s));
 
 /* these are in xhistory.c  */
 Boolean MoveHistoryIsUp P((void));
