@@ -5,7 +5,8 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Free
+ * Software Foundation, Inc.
  *
  * XBoard borrows its colors and the bitmaps.xchess bitmap set from XChess,
  * which was written and is copyrighted by Wayne Christopher.
@@ -270,7 +271,7 @@ InitJAWS()
 
 		AdaptMenu();
 		menuBarText[0][8] = menuBarText[0][7]; menuBarText[0][7] = "&JAWS";
-		for(i=0; i<9; i++) menuBarText[1][i] = menuBarText[0][i];
+		for(i=0; i<9; i++) menuBarText[2][i] = menuBarText[1][i] = menuBarText[0][i];
 	}
 
 	hAccelJAWS = CreateAcceleratorTable(acceleratorsJAWS, 14);
